@@ -7,8 +7,8 @@ of stack usage.
 """
 
 from xdis.opcodes.base import (
-    def_op, finalize_opcodes, init_opdata,
-    update_pj2)
+    def_op, finalize_opcodes, format_extended_arg,
+    init_opdata, update_pj2)
 import xdis.opcodes.opcode_25 as opcode_25
 
 version = 2.6
@@ -17,9 +17,13 @@ l = locals()
 init_opdata(l, opcode_25, version)
 
 # Below are opcode changes since Python 2.5
-def_op(l, 'STORE_MAP', 54, 3, 2)
+def_op(l, 'STORE_MAP', 54, 3, 1)
 
 # FIXME remove (fix uncompyle6)
 update_pj2(globals(), l)
 
+opcode_arg_fmt = {
+    'EXTENDED_ARG': format_extended_arg,
+}
+
 finalize_opcodes(l)
